@@ -1,10 +1,3 @@
-extern crate debug_helper;
-extern crate once_cell;
-extern crate regex;
-
-#[cfg(feature = "serde")]
-extern crate serde;
-
 use std::cmp::Ordering;
 use std::convert::TryFrom;
 use std::fmt::{self, Debug, Display, Formatter};
@@ -253,7 +246,7 @@ impl Display for Ipv6Cidr {
 impl PartialOrd for Ipv6Cidr {
     #[inline]
     fn partial_cmp(&self, other: &Ipv6Cidr) -> Option<Ordering> {
-        Some(self.cmp(&other))
+        Some(self.cmp(other))
     }
 }
 
